==> mingw-w64-clang-aarch64-kiconthemes-6.0.0-1-any.pkg.tar.zst: clangarm64/lib/cmake/KF6IconThemes/KF6IconThemesTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF6::IconWidgets" for configuration "Release"
set_property(TARGET KF6::IconWidgets APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6::IconWidgets PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libKF6IconWidgets.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Svg;KF6::I18n;KF6::ConfigWidgets;KF6::WidgetsAddons"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libKF6IconWidgets.dll"
  )

list(APPEND _cmake_import_check_targets KF6::IconWidgets )
list(APPEND _cmake_import_check_files_for_KF6::IconWidgets "${_IMPORT_PREFIX}/lib/libKF6IconWidgets.dll.a" "${_IMPORT_PREFIX}/bin/libKF6IconWidgets.dll" )

# Import target "KF6::IconThemes" for configuration "Release"
set_property(TARGET KF6::IconThemes APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6::IconThemes PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libKF6IconThemes.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Svg;KF6::Archive;KF6::I18n;KF6::ColorScheme;Qt6::DBus"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libKF6IconThemes.dll"
  )

list(APPEND _cmake_import_check_targets KF6::IconThemes )
list(APPEND _cmake_import_check_files_for_KF6::IconThemes "${_IMPORT_PREFIX}/lib/libKF6IconThemes.dll.a" "${_IMPORT_PREFIX}/bin/libKF6IconThemes.dll" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> mingw-w64-clang-aarch64-kiconthemes-6.2.0-1-any.pkg.tar.zst: clangarm64/lib/cmake/KF6IconThemes/KF6IconThemesTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF6::IconWidgets" for configuration "Release"
set_property(TARGET KF6::IconWidgets APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6::IconWidgets PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libKF6IconWidgets.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Svg;KF6::I18n;KF6::ConfigWidgets;KF6::WidgetsAddons"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libKF6IconWidgets.dll"
  )

list(APPEND _cmake_import_check_targets KF6::IconWidgets )
list(APPEND _cmake_import_check_files_for_KF6::IconWidgets "${_IMPORT_PREFIX}/lib/libKF6IconWidgets.dll.a" "${_IMPORT_PREFIX}/bin/libKF6IconWidgets.dll" )

# Import target "KF6::IconThemes" for configuration "Release"
set_property(TARGET KF6::IconThemes APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6::IconThemes PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/libKF6IconThemes.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Svg;KF6::Archive;KF6::I18n;KF6::ColorScheme"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/libKF6IconThemes.dll"
  )

list(APPEND _cmake_import_check_targets KF6::IconThemes )
list(APPEND _cmake_import_check_files_for_KF6::IconThemes "${_IMPORT_PREFIX}/lib/libKF6IconThemes.dll.a" "${_IMPORT_PREFIX}/bin/libKF6IconThemes.dll" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
